@@ -5,14 +5,14 @@ use warnings;
 package #
         Pod::Weaver::Section::Badges::PluginSearcher;
 
-our $VERSION = '0.0300'; # VERSION
+our $VERSION = '0.0400'; # VERSION
 
 use Moose;
 use Module::Pluggable search_path => ['Badge::Depot::Plugin'], require => 1;
 
 package Pod::Weaver::Section::Badges;
 
-our $VERSION = '0.0300'; # VERSION
+our $VERSION = '0.0400'; # VERSION
 # ABSTRACT: Add (or append) a section with badges
 
 use Moose;
@@ -110,12 +110,25 @@ around BUILDARGS => sub {
     $class->$next($args);
 };
 
+sub main_module {
+    my $self = shift;
+    my $input = shift;
+
+    # Use the main_module as defined by Dist::Zilla if it is available
+    return $input->{'zilla'}->main_module->name if exists $input->{'zilla'};
+
+    # Taken from Dist::Zilla
+    # If your distribution is Foo-Bar, and lib/Foo/Bar.pm exists, that's the main_module.
+    (my $guess = 'lib/' . $input->{'meta'}{'name'} . '.pm') =~ s{-}{/}g;
+    return -e $guess ? $guess : undef;
+}
+
 sub weave_section {
     my $self = shift;
     my $document = shift;
     my $input = shift;
 
-    return if $self->main_module_only && $input->{'filename'} ne $input->{'zilla'}->main_module->name;
+    return if $self->main_module_only && $input->{'filename'} ne $self->main_module($input);
 
     my $badge_objects = $self->create_badges;
     return if !scalar @$badge_objects;
@@ -165,7 +178,7 @@ Pod::Weaver::Section::Badges::PluginSearcher - Add (or append) a section with ba
 
 =head1 VERSION
 
-Version 0.0300, released 2016-01-26.
+Version 0.0400, released 2016-01-27.
 
 
 
